@@ -21,16 +21,10 @@
 // 17.4.1.2 Headers, sstream
 
 #include <sstream>
-#ifdef DEBUG_ASSERT
-#include <assert.h>
-#endif
+#include <debug_assert.h>
 
 
 int main(void)
 {
   return 0;
 }
-
-
-
-
